==> keycloak-session-starter-1.2.6-sources.jar: digital/nedra/commons/starter/keycloak/session/KeycloakAutoConfiguration.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.keycloak.session;

import static digital.nedra.commons.starter.security.utils.Constants.COMMON_PRIORITY;

import javax.annotation.PostConstruct;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.AutoConfigureOrder;
import org.springframework.boot.autoconfigure.security.oauth2.client.OAuth2ClientProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;

@Configuration
@ComponentScan
@EnableConfigurationProperties({OAuth2ClientProperties.class})
@PropertySource(value = "classpath:keycloak-starter.properties", encoding = "UTF-8")
@Slf4j
@AutoConfigureOrder(COMMON_PRIORITY)
public class KeycloakAutoConfiguration {
  @PostConstruct
  public void init() {
    log.info("Starter: keycloak-starter started");
  }
}

==> keycloak-session-starter-2.0.0-sources.jar: digital/nedra/commons/starter/keycloak/session/KeycloakAutoConfiguration.java <==
/*
 * Copyright 2022 Nedra Team
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package digital.nedra.commons.starter.keycloak.session;

import static digital.nedra.commons.starter.security.utils.Constants.COMMON_PRIORITY;

import jakarta.annotation.PostConstruct;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.AutoConfigureOrder;
import org.springframework.boot.autoconfigure.security.oauth2.client.OAuth2ClientProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.PropertySource;

@Configuration
@ComponentScan
@EnableConfigurationProperties({OAuth2ClientProperties.class})
@PropertySource(value = "classpath:keycloak-starter.properties", encoding = "UTF-8")
@Slf4j
@AutoConfigureOrder(COMMON_PRIORITY)
public class KeycloakAutoConfiguration {
  @PostConstruct
  public void init() {
    log.info("Starter: keycloak-starter started");
  }
}
